@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 1998-2012 Free Software Foundation, Inc.
+# Copyright (C) 1998-2021 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Test to see if defining INSTALL_DATA causes problems.  From EGCS
 # list.
@@ -29,4 +29,5 @@ $ACLOCAL
 $AUTOMAKE
 
 grep '^DATA =' Makefile.in | grep 'INSTALL_DATA' && exit 1
-exit 0
+
+:
